@@ -64,6 +64,7 @@ our @EXPORT = qw(
 	     NV_UNSET_FLAG
 
 	     %settings
+	     logName
 	     setLogFH
 	     dblog
 	     );
@@ -111,6 +112,7 @@ use constant NV_UNSET_FLAG => 3;
 # Real simple logging
 
 my $doLogging = 0;
+my $outLogName;
 my $logFH = undef;
 my $OUT = undef;
 our $ldebug;
@@ -128,8 +130,7 @@ sub enableLogger {
 	}
 	return;
     }
-    my $outLogName;
-    $DB::outLogName = $outLogName = shift;
+    $outLogName = shift;
     return unless $outLogName;
     if (ref $outLogName eq 'GLOB') {
 	# Make sure we can write to it -- we die if we can't
@@ -172,6 +173,7 @@ sub closeLogger {
 
 sub dblog {
     if (@_ && $doLogging && $logFH) {
+	local *DB::sub; # allows using dblog() inside DB::sub
 	print $logFH map { wide_char_safe_encode($_)} @_;
 	# End with a newline
 	print $logFH "\n" unless substr($_[-1], -1, 1) eq "\n";
@@ -182,6 +184,10 @@ sub setLogFH {
     $logFH = $_[0];
 }
 
+sub logName {
+    $outLogName;
+}
+
 sub setDefaultOutput {
     $OUT = shift;
 }
@@ -207,9 +213,9 @@ sub encodeData($$) {
 	my $str = safe_dump($str);
 	if ($@) {
 	    $str = (substr($str, 0, 100) . '...') if length($str) > 100;
-	    dblog("encodeData('$str') => [$@]\n") if $ldebug;
+	    dblog("encodeData('$str') => [$@]\n");
 	} else {
-	    dblog("encodeData('$str') => ['$finalStr']\n") if $ldebug;
+	    dblog("encodeData('$str') => ['$finalStr']\n");
 	}
     }
     return $finalStr;
